@@ -55,5 +55,6 @@ package com.openexchange.mailfilter.json.ajax.json.fields;
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
 public enum MoveActionField {
-    into;
+    into,
+    copy
 }
